@@ -5,7 +5,7 @@ use File::Find::Object;
 use File::Spec::Functions qw(catfile);
 use File::stat;
 
-our $VERSION = '0.97_02';
+our $VERSION = '0.97_03';
 $VERSION =~ s/_//; ## no critic
 
 sub order { 15 }
@@ -31,10 +31,12 @@ sub analyse {
     my $finder = File::Find::Object->new({
         depth => 1,
     }, $distdir);
+    my %seen; # GH-83
     while(defined(my $name = $finder->next)) {
         $name =~ s|\\|/|g if $^O eq 'MSWin32';
         (my $path = $name) =~ s!^\Q$distdir\E(?:/|$)!! or next;
         next if $path eq '';
+        next if $seen{$path}++;
 
         if (-d $name) {
             $dirs{$path} ||= {};
@@ -185,7 +187,8 @@ sub _make_no_index_regex {
         my @entries = ref $no_index->{$type} eq ref []
             ? @{ $no_index->{$type} }
             : ( $no_index->{$type} );
-        push @ignore, map {"^$_$rest"} @entries;
+        # entries may possibly have escape chars; DAGOLDEN/Class-InsideOut-0.90_01.tar.gz
+        push @ignore, map {s/\\/\\\\/g; "^$_$rest"} @entries;
     }
     return unless @ignore;
 
