@@ -4,7 +4,7 @@ use strict;
 use File::Spec::Functions qw(catfile);
 use Software::LicenseUtils;
 
-our $VERSION = '0.97_02';
+our $VERSION = '0.97_03';
 $VERSION =~ s/_//; ## no critic
 
 sub order { 100 }
@@ -31,7 +31,8 @@ sub analyse {
     my $files = $me->d->{files_array} || [];
 
     # check if there's a LICEN[CS]E file
-    if (my ($file) = grep {$_ =~ /^(?:LICEN[CS]E|COPYING)$/} @$files) {
+    # (also accept LICENSE.txt etc; RT #114247)
+    if (my ($file) = grep {$_ =~ /^(?:LICEN[CS]E|COPYING)\b/} @$files) {
         $me->d->{license} .= " defined in $file";
         $me->d->{external_license_file}=$file;
     }
